---
vid: KHV023
title: Denial of Service to Kubernetes API Server
categories: [Denial Of Service]
---

# {{ page.vid }} - {{ page.title }}

## Issue description

Cluster is found to be vulnerable to CVE-2019-1002100. Please see the Vulnerability description for additional information.

## Remediation

Please see the Vulnerability description for remediation.

## References

- [Kubernetes API Server Patch DoS Vulnerability (CVE-2019-1002100)](https://blog.aquasec.com/kubernetes-vulnerability-cve-2019-1002100)